########################################################################
# PORT TOOLS
########################################################################

case $(hostname -s) in
    x13)     PKGOPT="-Dsnap"; ;;
    openbsd) PKGOPT="-Dsnap"; ;;
esac

MAKE_JOBS=$(sysctl -n hw.ncpuonline)

alias refake="rm -f pkg/*.orig; make clean=fake && make fake"
alias reinstall="remake && make reinstall"


make-install() {
    make install \
    && doas pkg_add -aa "$(make show=FULLPKGNAME)"
}
make-reinstall() {
    remake \
    && doas pkg_add -aa "$(make show=FULLPKGNAME)"
}

########################################################################
# OPENBSD PORT TOOLS
########################################################################

# CVS
export CVSROOT=sdk@cvs.openbsd.org:/cvs
alias cvs-diff="doas -u sdk cvs -d $CVSROOT diff -uNp"
alias cvs-commit="doas -u sdk cvs -d $CVSROOT commit"
alias cvs-update="doas -u sdk cvs -z1 -d $CVSROOT -q up -Pd -A"

cvs-update-all() {(
    set -x
    cd /usr/src      && cvs-update
    cd /usr/xenocara && cvs-update
    cd /usr/ports    && cvs-update
    cd /usr/www      && cvs-update
)}

alias cvs-release="doas -u sdk cvs -d $CVSROOT release"
alias cvs-checkout="doas -u sdk cvs -z 1 -qd $CVSROOT checkout -P"
cvs-import-simulate() {
    doas -u sdk cvs -d sdk@cvs.openbsd.org:/cvs \
        -n import ports/$(dirname $PWD)/$(basename $PWD) sdk sdk_$(date +"%Y%m%d")
}
cvs-sync-sunny() {
    rsync -arv --delete /usr/ports/ root@sunny:/usr/ports/
    rsync -arv --delete /usr/src/ root@sunny:/usr/src/
    rsync -arv --delete /usr/xenocara/ root@sunny:/usr/xenocara/
}

full-update() {(
    set -x
    pkg_add -u
    cvs-update-all
    doas sysupgrade -sn
)}

set_autoconf() {
    set -x
    export AUTOMAKE_VERSION=1.16
    export AUTOCONF_VERSION=2.69
    set +x
}

# PORTS
portclean() {(
    set -x
    cd /usr/ports
    doas rm -rf pobj/* plist logs packages bulk update distfiles/*
    mkdir -p plist logs packages bulk update
    doas make fix-permissions
)}
pmark() { pwd > /var/cache/pmark; }
p()  { cd "$(</var/cache/pmark)"; }
pj() { cd "/usr/ports/$(portjump $1)"; }
po() { cd "$(</var/cache/pmark)" && cd "$(make show=WRKSRC)"; }
alias portsweep='doas find . \( -name "*.orig" -or -empty \) -delete'
pdiff() {(
    pwd | fgrep -q '/usr/ports/' || return 1
    set -A N $(make show="PKGNAME EPOCH REVISION")
    PN="${N[0]}${N[1]:+v${N[1]}}${N[2]:+p${N[2]}}"
    PD=$(pwd | cut -d"/" -f4,5)
    cd /usr/ports
    doas -u sdk cvs -d sdk@cvs.openbsd.org:/cvs diff -uNp "${PD}" \
        > "/home/sdk/diffs/${PN}.diff"
    echo "/home/sdk/diffs/${PN}.diff"

    )}
alias port-modgo-update='make MODGO_VERSION=latest modgo-gen-modules > modules.inc'

# DPB

proot-rebuild() {
    doas proot -c /etc/proot.conf
    doas chroot /home/dpb pkg_add -Dsnap ccache
}

alias proot-do="doas chroot /home/dpb/"
alias dpb-control="ssh openbsd.codevoid.de \"doas nc -U /usr/ports/logs/amd64/control-openbsd-*\""
dpb-log() {
    ssh openbsd.codevoid.de "tail -n 500 /usr/ports/logs/amd64/paths/$1.log"
}
dpb-logf() {
    ssh openbsd.codevoid.de "tail -n 500 -f /usr/ports/logs/amd64/paths/$1.log"
}

